@@ -74,7 +74,6 @@ typedef struct _GdlDockLayoutUIData GdlDockLayoutUIData;
 
 struct _GdlDockLayoutUIData {
     GdlDockLayout    *layout;
-    
     GtkWidget        *locked_check;
     GtkTreeSelection *selection;
 };
@@ -214,7 +213,8 @@ gdl_dock_layout_dispose (GObject *object)
             layout->_priv->items_model = NULL;
             layout->_priv->layouts_model = NULL;
         }
-
+        
+        xmlFreeDoc(layout->_priv->doc);
         g_free (layout->_priv);
         layout->_priv = NULL;
     }
@@ -336,7 +336,7 @@ update_items_model (GdlDockLayout *layout)
                 if (l) {
                     /* found, update data */
                     g_object_get (item, 
-                                  "long_name", &long_name, 
+                                  "long-name", &long_name, 
                                   "locked", &locked, 
                                   NULL);
                     gtk_list_store_set (store, &iter, 
@@ -368,7 +368,7 @@ update_items_model (GdlDockLayout *layout)
         GdlDockObject *object = l->data;
         
         g_object_get (object, 
-                      "long_name", &long_name, 
+                      "long-name", &long_name, 
                       "locked", &locked, 
                       NULL);
         gtk_list_store_append (store, &iter);
@@ -692,7 +692,7 @@ gdl_dock_layout_construct_layouts_ui (GdlDockLayout *layout)
     ui_data->layout = layout;
     g_object_add_weak_pointer (G_OBJECT (layout),
                                (gpointer *) &ui_data->layout);
-    g_object_set_data (G_OBJECT (container), "ui_data", ui_data);
+    g_object_set_data (G_OBJECT (container), "ui-data", ui_data);
     
     /* get ui widget references */
     layouts_list = glade_xml_get_widget (gui, "layouts_list");
@@ -715,9 +715,9 @@ gdl_dock_layout_construct_layouts_ui (GdlDockLayout *layout)
 
     /* connect signals */
     glade_xml_signal_connect_data (gui, "on_load_button_clicked",
-                                   GTK_SIGNAL_FUNC (load_layout_cb), ui_data);
+                                   G_CALLBACK (load_layout_cb), ui_data);
     glade_xml_signal_connect_data (gui, "on_delete_button_clicked",
-                                   GTK_SIGNAL_FUNC (delete_layout_cb), ui_data);
+                                   G_CALLBACK (delete_layout_cb), ui_data);
 
     g_signal_connect (container, "destroy", (GCallback) layout_ui_destroyed, NULL);
 
@@ -1151,7 +1151,7 @@ gdl_dock_layout_attach (GdlDockLayout *layout,
     layout->master = master;
     if (layout->master) {
         g_object_ref (layout->master);
-        g_signal_connect (layout->master, "layout_changed",
+        g_signal_connect (layout->master, "layout-changed",
                           (GCallback) gdl_dock_layout_layout_changed_cb,
                           layout);
     }
