@@ -37,6 +37,9 @@
 
 #include "libgdlmarshal.h"
 
+#ifndef __FUNCTION__
+#define __FUNCTION__ __func__
+#endif
 
 /* ----- Private prototypes ----- */
 
@@ -79,7 +82,7 @@ static void  gdl_dock_forall          (GtkContainer *container,
                                        gboolean      include_internals,
                                        GtkCallback   callback,
                                        gpointer      callback_data);
-static GtkType  gdl_dock_child_type   (GtkContainer *container);
+static GType  gdl_dock_child_type   (GtkContainer *container);
 
 static void     gdl_dock_detach       (GdlDockObject    *object,
                                        gboolean          recursive);
@@ -747,7 +750,7 @@ gdl_dock_forall (GtkContainer *container,
         (*callback) (GTK_WIDGET (dock->root), callback_data);
 }
 
-static GtkType
+static GType
 gdl_dock_child_type (GtkContainer *container)
 {
     return GDL_TYPE_DOCK_ITEM;
